require 'json'

class Pin::Error < StandardError

  # Possible Responses
  #
  # 200 - (OK) Successful request
  # 422 - (invalid_resource) One or more parameters were missing or invalid
  # 400 - (card_declined) The card was declined
  # 400 - (insufficient_funds) Bad api_key or not authorized to access a resource.
  # 400 - (suspected_fraud) The resource requested doesn't exist.
  # 400 - (expired_card) Clever screwed up.
  # 404 - (resource_not_found) No resource was found at this URL.
  # 500 - Server errors

  attr_accessor :status, :json_body

  def initialize(status, json_body)
    @status = status
    @json_body = JSON.parse(json_body)
  end

  def error
    @json_body['error']
  end

  def error_description
    @json_body['error_description']
  end

  def details
    @json_body
  end

  def to_s
    "HTTP Error #{@status}: #{error}"
  end
end